==> mingw-w64-aws-sdk-cpp-1.9.311-1.src.tar.zst: aws-sdk-cpp-1.9.311/aws-cpp-sdk-sagemaker/include/aws/sagemaker/model/ParallelismConfiguration.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/sagemaker/SageMaker_EXPORTS.h>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace SageMaker
{
namespace Model
{

  /**
   * <p>Configuration that controls the parallelism of the pipeline. By default, the
   * parallelism configuration specified applies to all executions of the pipeline
   * unless overridden.</p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ParallelismConfiguration">AWS
   * API Reference</a></p>
   */
  class AWS_SAGEMAKER_API ParallelismConfiguration
  {
  public:
    ParallelismConfiguration();
    ParallelismConfiguration(Aws::Utils::Json::JsonView jsonValue);
    ParallelismConfiguration& operator=(Aws::Utils::Json::JsonView jsonValue);
    Aws::Utils::Json::JsonValue Jsonize() const;


    /**
     * <p>The max number of steps that can be executed in parallel. </p>
     */
    inline int GetMaxParallelExecutionSteps() const{ return m_maxParallelExecutionSteps; }

    /**
     * <p>The max number of steps that can be executed in parallel. </p>
     */
    inline bool MaxParallelExecutionStepsHasBeenSet() const { return m_maxParallelExecutionStepsHasBeenSet; }

    /**
     * <p>The max number of steps that can be executed in parallel. </p>
     */
    inline void SetMaxParallelExecutionSteps(int value) { m_maxParallelExecutionStepsHasBeenSet = true; m_maxParallelExecutionSteps = value; }

    /**
     * <p>The max number of steps that can be executed in parallel. </p>
     */
    inline ParallelismConfiguration& WithMaxParallelExecutionSteps(int value) { SetMaxParallelExecutionSteps(value); return *this;}

  private:

    int m_maxParallelExecutionSteps;
    bool m_maxParallelExecutionStepsHasBeenSet;
  };

} // namespace Model
} // namespace SageMaker
} // namespace Aws

==> mingw-w64-aws-sdk-cpp-1.10.9-1.src.tar.zst: aws-sdk-cpp-1.10.9/aws-cpp-sdk-sagemaker/include/aws/sagemaker/model/ParallelismConfiguration.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/sagemaker/SageMaker_EXPORTS.h>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace SageMaker
{
namespace Model
{

  /**
   * <p>Configuration that controls the parallelism of the pipeline. By default, the
   * parallelism configuration specified applies to all executions of the pipeline
   * unless overridden.</p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/ParallelismConfiguration">AWS
   * API Reference</a></p>
   */
  class AWS_SAGEMAKER_API ParallelismConfiguration
  {
  public:
    ParallelismConfiguration();
    ParallelismConfiguration(Aws::Utils::Json::JsonView jsonValue);
    ParallelismConfiguration& operator=(Aws::Utils::Json::JsonView jsonValue);
    Aws::Utils::Json::JsonValue Jsonize() const;


    /**
     * <p>The max number of steps that can be executed in parallel. </p>
     */
    inline int GetMaxParallelExecutionSteps() const{ return m_maxParallelExecutionSteps; }

    /**
     * <p>The max number of steps that can be executed in parallel. </p>
     */
    inline bool MaxParallelExecutionStepsHasBeenSet() const { return m_maxParallelExecutionStepsHasBeenSet; }

    /**
     * <p>The max number of steps that can be executed in parallel. </p>
     */
    inline void SetMaxParallelExecutionSteps(int value) { m_maxParallelExecutionStepsHasBeenSet = true; m_maxParallelExecutionSteps = value; }

    /**
     * <p>The max number of steps that can be executed in parallel. </p>
     */
    inline ParallelismConfiguration& WithMaxParallelExecutionSteps(int value) { SetMaxParallelExecutionSteps(value); return *this;}

  private:

    int m_maxParallelExecutionSteps;
    bool m_maxParallelExecutionStepsHasBeenSet = false;
  };

} // namespace Model
} // namespace SageMaker
} // namespace Aws
